pub struct TraitDecl {
pub name: Ident,
pub methods: Vec<TraitMethod>,
pub span: Span,
}Expand description
A trait: a set of method signatures a type conforms to explicitly.
Conformance is only ever declared by an impl Trait for Type block; there
is no structural conformance and no blanket implementation.
Fields
name: Identmethods: Vec<TraitMethod>span: SpanTrait Implementations